Index: /extensions/AMetaData/JpegMetaData/JpegMetaData.class.php
===================================================================
--- /extensions/AMetaData/JpegMetaData/JpegMetaData.class.php	(revision 7518)
+++ /extensions/AMetaData/JpegMetaData/JpegMetaData.class.php	(revision 7519)
@@ -107,4 +107,6 @@
  * |         |            |   . Implement keywords as magic tag
  * |         |            |
+ * |         |            | * mantis bug:1978
+ * |         |            |   . Some meta names are not translated in french
  * |         |            |
  * |         |            |
@@ -796,7 +798,12 @@
           return($num);
         case "Author.Keywords":
-          $list=array_flip(array_flip(explode(',', str_replace(array('/', '|', ', '), ',', $value))));
+          $list=array_flip(array_flip(explode(',', str_replace(array('/', '|', ','), ',', $value))));
           sort($list);
-          return(implode(',', $list));
+          $tmp=array();
+          foreach($list as $key=>$val)
+          {
+            if(trim($val)!='') $tmp[]=trim($val);
+          }
+          return($tmp);
           break;
         default:
Index: /extensions/AMetaData/admin/amd_metadata_database_database.tpl
===================================================================
--- /extensions/AMetaData/admin/amd_metadata_database_database.tpl	(revision 7518)
+++ /extensions/AMetaData/admin/amd_metadata_database_database.tpl	(revision 7519)
@@ -90,4 +90,8 @@
     {
       ignoreOptions.push('xmp');
+    }
+    if($('#iFillDataBaseIgnore_com').get(0).checked)
+    {
+      ignoreOptions.push('com');
     }
 
@@ -254,5 +258,6 @@
             in_array('xmp', $amdConfig.amd_FillDataBaseExcludeFilters) and
             in_array('iptc', $amdConfig.amd_FillDataBaseExcludeFilters) and
-            in_array('xmp', $amdConfig.amd_FillDataBaseExcludeFilters)) }
+            in_array('xmp', $amdConfig.amd_FillDataBaseExcludeFilters) and
+            in_array('com', $amdConfig.amd_FillDataBaseExcludeFilters)) }
         <br>
         {'g003_ignoreMetadata'|@translate}<br>
@@ -270,5 +275,8 @@
               {/if}
               {if !in_array('xmp', $amdConfig.amd_FillDataBaseExcludeFilters)}
-              <label><input onclick='displayAnalyzedOption();' type="checkbox" id='iFillDataBaseIgnore_xmp' {if in_array('xmp', $amdConfig.amd_FillDataBaseIgnoreSchemas)}checked{/if}>&nbsp;XMP</label>
+              <label><input onclick='displayAnalyzedOption();' type="checkbox" id='iFillDataBaseIgnore_xmp' {if in_array('xmp', $amdConfig.amd_FillDataBaseIgnoreSchemas)}checked{/if}>&nbsp;XMP</label><br>
+              {/if}
+              {if !in_array('com', $amdConfig.amd_FillDataBaseExcludeFilters)}
+              <label><input onclick='displayAnalyzedOption();' type="checkbox" id='iFillDataBaseIgnore_com' {if in_array('com', $amdConfig.amd_FillDataBaseIgnoreSchemas)}checked{/if}>&nbsp;COM</label>
               {/if}
             </td>
Index: /extensions/AMetaData/admin/amd_metadata_database_status.tpl
===================================================================
--- /extensions/AMetaData/admin/amd_metadata_database_status.tpl	(revision 7518)
+++ /extensions/AMetaData/admin/amd_metadata_database_status.tpl	(revision 7519)
@@ -1,3 +1,11 @@
 <h2>{'g003_status_of_database'|@translate}</h2>
+
+{if $datas.warning2!=''}
+<div class="warnings">
+<p style="font-size: 120%;">{'g003_database_is_not_up_to_date'|@translate}</p>
+{$datas.warning2}
+</div>
+{/if}
+
 
 {if $amdConfig.amd_DisplayWarningsMessageStatus=='y'}
@@ -6,4 +14,5 @@
 {$datas.warning1}
 </div>
+{/if}
 
 <fieldset>
@@ -28,4 +37,7 @@
      <li><span class="mdInfo">XMP</span>{$datas.nfoMetadata.xmp}</li>
      {/if}
+     {if !in_array('com', $amdConfig.amd_FillDataBaseExcludeFilters)}
+     <li><span class="mdInfo">COM</span>{$datas.nfoMetadata.com}</li>
+     {/if}
      <li><span class="mdInfo">{'g003_personnal'|@translate}</span>{$datas.nfoMetadata.userDefined}</li>
     </ul>
@@ -45,4 +57,3 @@
 
 
-{/if}
 
Index: /extensions/AMetaData/admin/amd_metadata_select.tpl
===================================================================
--- /extensions/AMetaData/admin/amd_metadata_select.tpl	(revision 7518)
+++ /extensions/AMetaData/admin/amd_metadata_select.tpl	(revision 7519)
@@ -224,4 +224,7 @@
       <option value="iptc" {if $datas.config_GetListTags_FilterType=="iptc"}selected{/if}>Iptc</option>
       {/if}
+      {if !in_array('com', $amdConfig.amd_FillDataBaseExcludeFilters)}
+      <option value="com" {if $datas.config_GetListTags_FilterType=="com"}selected{/if}>Com</option>
+      {/if}
     </select>
   </label>
Index: /extensions/AMetaData/amd_aip.class.inc.php
===================================================================
--- /extensions/AMetaData/amd_aip.class.inc.php	(revision 7518)
+++ /extensions/AMetaData/amd_aip.class.inc.php	(revision 7519)
@@ -558,6 +558,42 @@
     $template->set_filename('sheet_page', dirname(__FILE__).'/admin/amd_metadata_database_status.tpl');
 
+    $warning2='';
+    $sql="SELECT tagId
+          FROM ".$this->tables['used_tags']."
+          WHERE newFromLastUpdate='y'";
+    $result=pwg_query($sql);
+    if($result)
+    {
+      $tmp=array();
+      $tagSchema='';
+      while($row=pwg_db_fetch_assoc($result))
+      {
+        if(preg_match('/^([a-z0-9]*)\..*/i', $row['tagId'], $tagSchema))
+        {
+          if(!in_array($tagSchema[1],$this->config['amd_FillDataBaseIgnoreSchemas'])) $tmp[]=$row['tagId'];
+        }
+      }
+      if(count($tmp)>0)
+      {
+        $ul='';
+        foreach($tmp as $val)
+        {
+          $ul.='<li>'.$val.'</li>';
+        }
+        if(count($tmp)>1)
+        {
+          $warning2=sprintf(GPCCore::BBtoHTML(l10n('g003_databaseWarning2_n')),$ul);
+        }
+        else
+        {
+          $warning2=sprintf(GPCCore::BBtoHTML(l10n('g003_databaseWarning2_1')),$ul);
+        }
+      }
+    }
+
+
     $datas=array(
       'urlRequest' => $this->getAdminLink('ajax'),
+      'warning2' => $warning2,
       'warning1' => GPCCore::BBtoHTML(l10n('g003_databaseWarning1')),
       'nfoMetadata' => Array(
@@ -566,4 +602,5 @@
           'magic' => 0,
           'xmp' => 0,
+          'com' => 0,
           'userDefined' => 0,
           'numOfPictures' => 0,
@@ -591,4 +628,8 @@
           FROM ".$this->tables['used_tags']."
           WHERE tagId LIKE 'xmp.%'
+          UNION
+          SELECT SUM(numOfImg), 'com'
+          FROM ".$this->tables['used_tags']."
+          WHERE tagId LIKE 'com.%'
           UNION
           SELECT SUM(numOfImg), 'userDefined'
@@ -619,4 +660,5 @@
              $row['type']=='magic' or
              $row['type']=='xmp' or
+             $row['type']=='com' or
              $row['type']=='userDefined') $datas['nfoMetadata']['nfoRows']+=$row['nb'];
         }
Index: /extensions/AMetaData/amd_aip_install.class.inc.php
===================================================================
--- /extensions/AMetaData/amd_aip_install.class.inc.php	(revision 7518)
+++ /extensions/AMetaData/amd_aip_install.class.inc.php	(revision 7519)
@@ -174,4 +174,5 @@
       'magic.Author.Copyright',
       'magic.Author.ImageTitle',
+      'magic.Author.Keywords',
       'magic.GPS.Altitude',
       'magic.GPS.Latitude',
Index: /extensions/AMetaData/amd_install.class.inc.php
===================================================================
--- /extensions/AMetaData/amd_install.class.inc.php	(revision 7518)
+++ /extensions/AMetaData/amd_install.class.inc.php	(revision 7519)
@@ -47,4 +47,5 @@
       $this->initConfig();
       $this->loadConfig();
+      $this->config['amd_FillDataBaseIgnoreSchemas']=> array('exif', 'iptc', 'xmp', 'com');
       $this->config['installed']=AMD_VERSION2;
       $this->config['newInstall']='y';
@@ -59,4 +60,5 @@
   `numOfImg` int(10) unsigned NOT NULL default '0',
   `translatedName` varchar(200) NOT NULL default '',
+  `newFromLastUpdate` char(1) NOT NULL default 'n',
   PRIMARY KEY  (`numId`),
   KEY `by_tag` (`tagId`)
@@ -177,5 +179,8 @@
           $this->config['newInstall']='n';
           $this->updateFrom_000400();
-          break;
+        case '00.05.01':
+        case '00.05.02':
+          $this->config['newInstall']='n';
+          $this->updateFrom_000502();
         default:
           /*
@@ -183,5 +188,5 @@
            * database with default values
            */
-          $this->initializeDatabase();
+          $this->fillDatabase();
           break;
       }
@@ -247,5 +252,24 @@
     }
 
-
+    /**
+     * update the database from the release 0.5.2
+     */
+    private function updateFrom_000502()
+    {
+      /*
+       * alter existing tables
+       */
+      $tablesUpdate=array(
+        $this->tables['used_tags'] => array(
+          'newFromLastUpdate' => "ADD COLUMN `newFromLastUpdate` CHAR(1)  NOT NULL DEFAULT 'n' AFTER `translatedName`",
+        )
+      );
+
+      $tablef=new GPCTables(array($this->tables['used_tags']));
+
+      if(count($tablesUpdate)>0) $tablef->updateTablesFields($tablesUpdate);
+
+      unset($tablesUpdate);
+    }
 
 
@@ -253,5 +277,20 @@
      * fill the database with some default value
      */
-    private function initializeDatabase()
+    private function fillDatabase()
+    {
+      if($this->config['newInstall']=='y')
+      {
+        $this->initializeDatabaseContent();
+      }
+      else
+      {
+        $this->updateDatabaseContent();
+      }
+    }
+
+    /**
+     * reset and initialize the database content (for a fresh install)
+     */
+    private function initializeDatabaseContent()
     {
       global $user;
@@ -269,7 +308,14 @@
        * fill the 'used_tags' table with default values
        */
-      foreach(AMD_JpegMetaData::getTagList(Array('filter' => AMD_JpegMetaData::TAGFILTER_IMPLEMENTED, 'xmp' => true, 'maker' => true, 'iptc' => true)) as $key => $val)
-      {
-        $sql="INSERT INTO ".$this->tables['used_tags']." VALUES('', '".$key."', '".(($val['translatable'])?'y':'n')."', '".$val['name']."', 0, '".addslashes(L10n::get($val['name']))."');";
+      foreach(AMD_JpegMetaData::getTagList(
+                Array('filter' => AMD_JpegMetaData::TAGFILTER_IMPLEMENTED,
+                      'xmp' => true,
+                      'maker' => true,
+                      'iptc' => true,
+                      'com' => true)
+              ) as $key => $val
+             )
+      {
+        $sql="INSERT INTO ".$this->tables['used_tags']." VALUES('', '".$key."', '".(($val['translatable'])?'y':'n')."', '".$val['name']."', 0, '".addslashes(L10n::get($val['name']))."', 'n');";
         pwg_query($sql);
       }
@@ -292,4 +338,66 @@
     }
 
+    /**
+     * update the database content (for an update)
+     */
+    private function updateDatabaseContent()
+    {
+      global $user;
+
+      L10n::setLanguage('en_UK');
+
+      pwg_query("INSERT INTO ".$this->tables['images']."
+                  SELECT id, 'n', 0
+                    FROM ".IMAGES_TABLE."
+                    WHERE id NOT IN (SELECT imageId FROM ".$this->tables['images'].")");
+
+      $tagList=array();
+      $sql="SELECT tagId FROM ".$this->tables['used_tags'];
+      $result=pwg_query($sql);
+      if($result)
+      {
+        while($row=pwg_db_fetch_row($result))
+        {
+          $tagList[$row[0]]='';
+        }
+      }
+
+      /*
+       * fill the 'used_tags' table with default values
+       */
+      foreach(AMD_JpegMetaData::getTagList(
+                Array('filter' => AMD_JpegMetaData::TAGFILTER_IMPLEMENTED,
+                      'xmp' => true,
+                      'maker' => true,
+                      'iptc' => true,
+                      'com' => true)
+              ) as $key => $val
+             )
+      {
+        if(!array_key_exists($key, $tagList))
+        {
+          $sql="INSERT IGNORE INTO ".$this->tables['used_tags']." VALUES('', '".$key."', '".(($val['translatable'])?'y':'n')."', '".$val['name']."', 0, '".addslashes(L10n::get($val['name']))."', 'y');";
+          pwg_query($sql);
+        }
+      }
+
+      /*
+       * exclude unauthorized tag with the 'amd_FillDataBaseExcludeTags' option
+       */
+      if(count($this->config['amd_FillDataBaseExcludeTags']))
+      {
+        $sql="";
+        foreach($this->config['amd_FillDataBaseExcludeTags'] as $key => $tag)
+        {
+          if($sql!="") $sql.=" OR ";
+          $sql.=" tagId LIKE '$tag' ";
+        }
+        $sql="DELETE FROM ".$this->tables['used_tags']."
+              WHERE ".$sql;
+        pwg_query($sql);
+      }
+    }
+
+
     private function buildDefaultGroup()
     {
Index: /extensions/AMetaData/amd_root.class.inc.php
===================================================================
--- /extensions/AMetaData/amd_root.class.inc.php	(revision 7518)
+++ /extensions/AMetaData/amd_root.class.inc.php	(revision 7519)
@@ -37,5 +37,5 @@
   {
     global $user;
-    $this->setPluginName("AMetaData");
+    $this->setPluginName("Advanced MetaData");
     $this->setPluginNameFiles("amd");
     parent::__construct($prefixeTable, $filelocation);
@@ -111,5 +111,6 @@
      *           'iptc',
      *           'xmp',
-     *           'magic')
+     *           'magic',
+     *           'com')
      *
      * ==> amd_DisplayWarningsMessageStatus : 'y' or 'n'
@@ -240,4 +241,5 @@
           'xmp' => !isset($schemas['xmp']),
           'magic' => !isset($schemas['magic']),
+          'com' => !isset($schemas['com']),
         )
       );
@@ -582,4 +584,5 @@
 
     }
+print_r($this->config['amd_FillDataBaseIgnoreSchemas']);
     $this->saveConfig();
   }
Index: /extensions/AMetaData/amd_version.inc.php
===================================================================
--- /extensions/AMetaData/amd_version.inc.php	(revision 7518)
+++ /extensions/AMetaData/amd_version.inc.php	(revision 7519)
@@ -17,6 +17,6 @@
   if (!defined('PHPWG_ROOT_PATH')) die('Hacking attempt!');
 
-  define('AMD_VERSION',  '0.5.2');
-  define('AMD_VERSION2', '00.05.02');
+  define('AMD_VERSION',  '0.5.3');
+  define('AMD_VERSION2', '00.05.03');
   define('AMD_GPC_NEEDED', '3.2.0');
 ?>
Index: /extensions/AMetaData/language/en_UK/plugin.lang.php
===================================================================
--- /extensions/AMetaData/language/en_UK/plugin.lang.php	(revision 7518)
+++ /extensions/AMetaData/language/en_UK/plugin.lang.php	(revision 7519)
@@ -1,4 +1,16 @@
 <?php
-
+/*
+ * How to translate metadata names and values ?
+ *
+ * Metadata names and values are not translated with a /language/*.lang.php file
+ * but they are stored in a .po and .mo files, respectively localized into
+ *  - /JpegMetaData/Locale/xx_XX/Tag.po
+ *  - /JpegMetaData/Locale/xx_XX/LC_MESSAGES/Tag.mo
+ *
+ * More information about GNU gettext l10n system and method to edit the .po & .mo
+ * files on wikipedia :
+ *  - http://en.wikipedia.org/wiki/GNU_gettext
+ *
+ */
 
 $lang['Grum Plugin Classes is not installed'] = '<b>Grum Plugin Classes</b> plugin is not installed';
@@ -343,6 +355,13 @@
 
 
-
-
+$lang['g003_database_is_not_up_to_date']="The repository is not up do date !";
+$lang['g003_databaseWarning2_1']="[p]A new metadata is available since the last update of the plugin:[/p][ul]%s[/ul]
+[p]
+To be exploited, it is necessary to update the repository.[/p]";
+$lang['g003_databaseWarning2_n']="[p]Some new metadatas are available since the last update of the plugin:[/p][ul]%s[/ul]
+[p]
+To be exploited, it is necessary to update the repository.[/p]";
+
+// help for metadata translation is given at the beginning of this file
 
 ?>
Index: /extensions/AMetaData/language/es_ES/plugin.lang.php
===================================================================
--- /extensions/AMetaData/language/es_ES/plugin.lang.php	(revision 7518)
+++ /extensions/AMetaData/language/es_ES/plugin.lang.php	(revision 7519)
@@ -1,3 +1,16 @@
 <?php
+/*
+ * How to translate metadata names and values ?
+ *
+ * Metadata names and values are not translated with a /language/*.lang.php file
+ * but they are stored in a .po and .mo files, respectively localized into
+ *  - /JpegMetaData/Locale/xx_XX/Tag.po
+ *  - /JpegMetaData/Locale/xx_XX/LC_MESSAGES/Tag.mo
+ *
+ * More information about GNU gettext l10n system and method to edit the .po & .mo
+ * files on wikipedia :
+ *  - http://en.wikipedia.org/wiki/GNU_gettext
+ *
+ */
 
 $lang['Grum Plugin Classes is not installed'] = 'El plugin <b>Grum Plugin Classes</b> no esta instalado';
@@ -16,5 +29,5 @@
 $lang['g003_performances'] = "Rendimiento";
 $lang['g003_setting_nb_items_per_request'] = "Numero de imágenes analizadas por demandas";
-$lang['g003_apply'] = "Afficher en écriture latineAplicar";
+$lang['g003_apply'] = "Aplicar";
 
 $lang['g003_numberOfAnalyzedPictures'] = "%d imágenes han sido objeto de un análisis y representan %d métadatos";
@@ -326,4 +339,26 @@
 
 
+/** ----------------------------------------------------------------------------
+ * new keys from releases 0.5.3
+ *
+ *
+ * need to be translated
+ * thanks :)
+ */
+$lang['g003_1_picture_in_caddie']="1 picture in caddie";
+$lang['g003_n_pictures_in_caddie']="%s pictures in caddie";
+$lang['g003_analyze_random_pictures'] = "The analysis focuses on %s images selected randomly among images that have never been analyzed, and adds to the existing repository";
+$lang['g003_invalid_random_number']="The number of images to process is not valid";
+
+
+$lang['g003_database_is_not_up_to_date']="The repository is not up do date !";
+$lang['g003_databaseWarning2_1']="[p]A new metadata is available since the last update of the plugin:[/p][ul]%s[/ul]
+[p]
+To be exploited, it is necessary to update the repository.[/p]";
+$lang['g003_databaseWarning2_n']="[p]Some new metadatas are available since the last update of the plugin:[/p][ul]%s[/ul]
+[p]
+To be exploited, it is necessary to update the repository.[/p]";
+
+// help for metadata translation is given at the beginning of this file
 
 ?>
Index: /extensions/AMetaData/language/fr_FR/plugin.lang.php
===================================================================
--- /extensions/AMetaData/language/fr_FR/plugin.lang.php	(revision 7518)
+++ /extensions/AMetaData/language/fr_FR/plugin.lang.php	(revision 7519)
@@ -1,3 +1,17 @@
 <?php
+
+/*
+ * How to translate metadata names and values ?
+ *
+ * Metadata names and values are not translated with a /language/*.lang.php file
+ * but they are stored in a .po and .mo files, respectively localized into
+ *  - /JpegMetaData/Locale/xx_XX/Tag.po
+ *  - /JpegMetaData/Locale/xx_XX/LC_MESSAGES/Tag.mo
+ *
+ * More information about GNU gettext l10n system and method to edit the .po & .mo
+ * files on wikipedia :
+ *  - http://en.wikipedia.org/wiki/GNU_gettext
+ *
+ */
 
 $lang['Grum Plugin Classes is not installed'] = 'Le plugin <b>Grum Plugin Classes</b> n\'est pas installé';
@@ -341,4 +355,13 @@
 $lang['g003_invalid_random_number']="Le nombre de photos à traiter est invalide";
 
+$lang['g003_database_is_not_up_to_date']="Le référentiel n'est pas à jour !";
+$lang['g003_databaseWarning2_1']="[p]Une nouvelle métadonnée est accessible suite à la dernière mise à jour du plugin :[/p][ul]%s[/ul]
+[p]
+Pour qu'elle puisse être exploitée, il est nécessaire de procéder à la mise à jour du référentiel.[/p]";
+$lang['g003_databaseWarning2_n']="[p]De nouvelles métadonnées sont accessibles suite à la dernière mise à jour du plugin :[/p][ul]%s[/ul]
+[p]
+Pour qu'elles puissent être exploitées, il est nécessaire de procéder à la mise à jour du référentiel.[/p]";
+
+// help for metadata translation is given at the beginning of this file
 
 
Index: /extensions/AMetaData/main.inc.php
===================================================================
--- /extensions/AMetaData/main.inc.php	(revision 7518)
+++ /extensions/AMetaData/main.inc.php	(revision 7519)
@@ -2,5 +2,5 @@
 /*
 Plugin Name: Advanced MetaData
-Version: 0.5.2
+Version: 0.5.3
 Description: An advanced metadata manager
 Plugin URI: http://piwigo.org/ext/extension_view.php?eid=364
@@ -126,5 +126,5 @@
 |         |            |   new package
 |         |            |
-| 0.x.y   | 2010/09/30 | * mantis bug:1894
+| 0.5.3   | 2010/09/30 | * mantis bug:1894
 |         |            |   . Error when filling the metadata repository
 |         |            |
@@ -163,4 +163,14 @@
 |         |            | * mantis bug:1294
 |         |            |   . filling database method
+|         |            |
+|         |            | * mantis bug:1975
+|         |            |   . Implement COM segment as a tag
+|         |            |
+|         |            | * mantis bug:1976
+|         |            |   . Implement keywords as magic tag
+|         |            |
+|         |            | * mantis bug:1978
+|         |            |   . Some meta names are not translated in french
+|         |            |
 |         |            |
 |         |            |

Index: /extensions/AMetaData/amd_ajax.php
===================================================================
--- /extensions/AMetaData/amd_ajax.php	(revision 7518)
+++ /extensions/AMetaData/amd_ajax.php	(revision 7519)
@@ -162,5 +162,6 @@
                ($_REQUEST['filterType']=="exif.maker.Pentax" and !in_array('maker', $this->config['amd_FillDataBaseExcludeFilters'])) or
                ($_REQUEST['filterType']=="xmp" and !in_array('xmp', $this->config['amd_FillDataBaseExcludeFilters'])) or
-               ($_REQUEST['filterType']=="iptc"  and !in_array('iptc', $this->config['amd_FillDataBaseExcludeFilters']))
+               ($_REQUEST['filterType']=="iptc"  and !in_array('iptc', $this->config['amd_FillDataBaseExcludeFilters'])) or
+               ($_REQUEST['filterType']=="com"  and !in_array('com', $this->config['amd_FillDataBaseExcludeFilters']))
                )) $_REQUEST['filterType']="";
 
@@ -659,5 +660,5 @@
      * @param String $orderType : order for the list (by tag 'tag' or by number of
      *                            pictures 'num')
      * @param String $filterType : filter for the list ('exif', 'xmp', 'iptc' or '')
      * @return String
      */
@@ -1533,5 +1534,6 @@
                    paut.tagId = 'xmp.digiKam:TagsList' OR
                    paut.tagId = 'xmp.lr:hierarchicalSubject' OR
-                   paut.tagId = 'iptc.Keywords');";
+                   paut.tagId = 'iptc.Keywords' OR
+                   paut.tagId = 'magic.Author.Keywords');";
       $result=pwg_query($sql);
       if($result)
@@ -1545,4 +1547,5 @@
              */
             $tmp=unserialize($row['value']);
+            if(!isset($tmp['values'])) $tmp=array('values'=>$tmp);
             foreach($tmp['values'] as $val)
             {
@@ -1636,5 +1639,6 @@
                    paut.tagId = 'xmp.digiKam:TagsList' OR
                    paut.tagId = 'xmp.lr:hierarchicalSubject' OR
-                   paut.tagId = 'iptc.Keywords');";
+                   paut.tagId = 'iptc.Keywords' OR
+                   paut.tagId = 'magic.Author.Keywords');";
       $result=pwg_query($sql);
       if($result)
@@ -1648,7 +1652,8 @@
              */
             $tmp=unserialize($row['value']);
+            if(!isset($tmp['values'])) $tmp=array('values'=>$tmp);
             foreach($tmp['values'] as $val)
             {
-              if($row['tagId']=='xmp.digiKam:TagsList')
+              if($row['tagId']=='xmp.digiKam:TagsList' or $row['tagId']=='xmp.lr:hierarchicalSubject')
               {
                 $list=explode($this->tagSeparators[$row['tagId']], $val);
@@ -659,5 +660,5 @@
      * @param String $orderType : order for the list (by tag 'tag' or by number of
      *                            pictures 'num')
-     * @param String $filterType : filter for the list ('exif', 'xmp', 'iptc' or '')
+     * @param String $filterType : filter for the list ('exif', 'xmp', 'iptc', 'com' or '')
      * @return String
      */